<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Factories\RNFFactory;
use \Exception as Exception;

class RNFService {
    protected $rnfFactory;

    public function __construct(RNFFactory $rnfFactory) {
        $this->rnfFactory = $rnfFactory;
    }

    private function params($conditions) {
        $params = [
            ':CDFILIAL'     => $conditions['CDFILIAL'],
            ':TCDFILIAL'    => $conditions['TCDFILIAL'],
            ':P_DTINI'      => $conditions['P_DTINI'],
            ':P_DTFIN'      => $conditions['P_DTFIN'],
            ':P_NUMINI'     => $conditions['P_NUMINI'],
            ':P_NUMFIN'     => $conditions['P_NUMFIN'],
            ':P_CDOPERADOR' => $conditions['P_CDOPERADOR']
        ];

        return $params;
    }

    public function findFiliais($conditions) {
        $params = $this->params($conditions);
        
        $result = $this->rnfFactory->findFiliais($params);
        
        return $result;
    }

    public function findCabecalho($conditions) {
        $params = $this->params($conditions);
        
        unset($params[':TCDFILIAL']);
        
        return $this->rnfFactory->findCabecalho($params);
    }

    public function findNotas($conditions) {
        $params = $this->params($conditions);
        
        if (isset($conditions['NUM_SEQ_HEADER'])) {
            $params['NUM_SEQ_HEADER'] = $conditions['NUM_SEQ_HEADER'];
        } else {
            $params['NUM_SEQ_HEADER'] = "";
        }
        
        unset($params[':TCDFILIAL']);
        
        return $this->rnfFactory->findNotas($params);
    }

    public function findItens($conditions) {
        $params = $this->params($conditions);
        
        unset($params[':TCDFILIAL']);
        
        if (isset($conditions['NUM_SEQ_HEADER'])) {
            $params['NUM_SEQ_HEADER'] = $conditions['NUM_SEQ_HEADER'];
        } else {
            $params['NUM_SEQ_HEADER'] = "";
        }
        
        if (isset($conditions['NUM_SEQ_CORPO'])) {
            $params['NUM_SEQ_CORPO'] = $conditions['NUM_SEQ_CORPO'];
        } else {
            $params['NUM_SEQ_CORPO'] = "";
        }
        
        return $this->rnfFactory->findItens($params);
    }

    public function findImpostos($conditions) {
        $params = $this->params($conditions);
        
        unset($params[':TCDFILIAL']);
        
        if (isset($conditions['NUM_SEQ_HEADER'])) {
            $params['NUM_SEQ_HEADER'] = $conditions['NUM_SEQ_HEADER'];
        } else {
            $params['NUM_SEQ_HEADER'] = "";
        }
        
        if (isset($conditions['NUM_SEQ_CORPO'])) {
            $params['NUM_SEQ_CORPO'] = $conditions['NUM_SEQ_CORPO'];
        } else {
            $params['NUM_SEQ_CORPO'] = "";
        }
        
        if (isset($conditions['NUM_SEQ_ITEM'])) {
            $params['NUM_SEQ_ITEM'] = $conditions['NUM_SEQ_ITEM'];
        } else {
            $params['NUM_SEQ_ITEM'] = "";
        }
        
        return $this->rnfFactory->findImpostos($params);
    }

    public function gerarRNF($row) {
        $result = [];

        if((isset($row['CDFILIAL'])) && (isset($row['DATAINI'])) && (isset($row['DATAFIN']))) {
            $params = [
                'CDFILIAL'   => $row['CDFILIAL'],
                'DATAINI'    => $row['DATAINI'],
                'DATAFIN'    => $row['DATAFIN'],
                'CDOPERADOR' => $row['CDOPERADOR']
            ];

            $resultGerarRNF = $this->rnfFactory->gerarRNF($params);

            if($resultGerarRNF) {
                $result = $this->rnfFactory->validaGeracaoRNF($params);
            }

            return $result;
        } else {
            throw new Exception("Coloque os dados nos campos da tela antes de gerar, 'Unidade' e 'Data de RNF'");
        }
    }

    public function verificaIntegracao() {
        $status = $this->rnfFactory->verificaIntegracao();
        
        if((!empty($status)) && ($status[0]['STATUS'] == "SUCCEEDED")) {
            return "Integração Online";
        } else {
            return "Integração Offline";
        }        
    }
}