<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RentProdResOpCadService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

    public function find($conditions) {
        $params = array(
            ':CDFILIAL' => $conditions['CDFILIAL'],
            ':CDANO'    => $conditions['CDANO'],
            ':NRORG'    => $conditions['NRORG']
        );

        return $this->entityManager->getConnection()->fetchAll(self::GET_RENTABILIDADE, $params);
    }

    const GET_RENTABILIDADE = "
        SELECT R.CDFILIAL, L.CDLOJA, L.CDLOJA || ' - ' || L.NMLOJA AS LABELLOJA, L.NMLOJA, R.VRROYALTIESPERC, 
                R.VRFPROPMARKPERC, R.VRGASTOSLOJA, R.VRODPERC, R.VRQFR, R.VRQFP, R.VRM2, R.CDANO, R.CDMES
            FROM RENTPRODOP R
                JOIN LOJA L
                    ON R.CDLOJA = L.CDLOJA
                        AND R.CDFILIAL = L.CDFILIAL
            WHERE R.CDFILIAL = :CDFILIAL
                AND R.CDANO = :CDANO
                AND R.NRORG = :NRORG
        ORDER BY L.CDLOJA, R.CDMES
    ";
    
    public function save($row) {
        $params = array(
            ':CDFILIAL'         => $row['CDFILIAL'],
            ':CDLOJA'           => $row['CDLOJA'],
            ':VRROYALTIESPERC'  => $row['VRROYALTIESPERC'],
            ':VRFPROPMARKPERC'  => $row['VRFPROPMARKPERC'],
            ':VRGASTOSLOJA'     => $row['VRGASTOSLOJA'],
            ':VRODPERC'         => $row['VRODPERC'],
            ':VRQFR'            => $row['VRQFR'],
            ':VRQFP'            => $row['VRQFP'],
            ':VRM2'             => $row['VRM2'],
            ':CDMES'            => $row['NMMES'],
            ':CDANO'            => $row['CDANO']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::INSERT_RENTABILIDADE, $params);
    }
    
    const INSERT_RENTABILIDADE = "
        INSERT INTO RENTPRODOP(CDFILIAL, CDLOJA, VRROYALTIESPERC, VRFPROPMARKPERC, VRGASTOSLOJA, VRODPERC, VRQFR, VRQFP, VRM2, CDMES, CDANO)
            VALUES(:CDFILIAL, :CDLOJA, :VRROYALTIESPERC, :VRFPROPMARKPERC, :VRGASTOSLOJA, :VRODPERC, :VRQFR, :VRQFP, :VRM2, :CDMES, :CDANO)
    ";
    
    public function update($row) {
        $params = array(
            ':CDFILIAL'         => $row['CDFILIAL'],
            ':CDLOJA'           => $row['CDLOJA'],
            ':VRROYALTIESPERC'  => $row['VRROYALTIESPERC'],
            ':VRFPROPMARKPERC'  => $row['VRFPROPMARKPERC'],
            ':VRGASTOSLOJA'     => $row['VRGASTOSLOJA'],
            ':VRODPERC'         => $row['VRODPERC'],
            ':VRQFR'            => $row['VRQFR'],
            ':VRQFP'            => $row['VRQFP'],
            ':VRM2'             => $row['VRM2'],
            ':CDMES'            => $row['NMMES'],
            ':CDANO'            => $row['CDANO']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::UPDATE_RENTABILIDADE, $params);
    }
    
    const UPDATE_RENTABILIDADE = "
        UPDATE RENTPRODOP
            SET VRM2            = :VRM2,
                VRQFR           = :VRQFR, 
                VRQFP           = :VRQFP, 
                VRODPERC        = :VRODPERC,
                VRGASTOSLOJA    = :VRGASTOSLOJA, 
                VRROYALTIESPERC = :VRROYALTIESPERC, 
                VRFPROPMARKPERC = :VRFPROPMARKPERC
            WHERE CDFILIAL = :CDFILIAL
                AND CDANO  = :CDANO
                AND CDLOJA = :CDLOJA
                AND CDMES  = :CDMES
    ";
    
    public function validacao($conditions) {
        $params = array(
            ':CDFILIAL' => $conditions['CDFILIAL'],
            ':CDLOJA'   => $conditions['CDLOJA'],
            ':CDMES'    => $conditions['NMMES'],
            ':CDANO'    => $conditions['CDANO'],
            ':NRORG'    => $conditions['NRORG']
        );

        return $this->entityManager->getConnection()->fetchAll(self::VALIDA_RENTABILIDADE_IGUAL, $params);
    }

    const VALIDA_RENTABILIDADE_IGUAL = "
        SELECT 1
            FROM RENTPRODOP R
            WHERE R.CDFILIAL = :CDFILIAL
                AND R.CDMES = :CDMES
                AND R.CDANO = :CDANO
                AND R.NRORG = :NRORG
                AND R.CDLOJA = :CDLOJA
    ";
}